/*
 * JBoss, Home of Professional Open Source
 *
 * Copyright 2013 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.picketlink.idm.credential;

import org.picketlink.idm.model.Agent;

/**
 * Represents the credentials the current user will use to authenticate, in addition to providing information about the current
 * state of the validation process.
 *
 * Only used during the authentication process
 *
 * @author Shane Bryzak
 */
public interface Credentials {
    public enum Status {
        UNVALIDATED, IN_PROGRESS, INVALID, VALID, EXPIRED
    };

    /**
     * <p>
     * Returns the {@link Agent} instance used to validate the credential.
     * </p>
     *
     * @return
     */
    Agent getValidatedAgent();

    /**
     * <p>
     * Returns the validation status.
     * </p>
     *
     * @return
     */
    Status getStatus();

    /**
     * <p>
     * Invalidates the credential.
     * </p>
     */
    void invalidate();
}
